#######################################
#### CODE FOR WAGGERSHAUSER ET AL #####




## LIBRARIES

library(tidyverse)
library(grid)
library(gridExtra)
library(DHARMa)



#################################################
###### GENETIC DISTANCE BETWEEN SEQUENCES #######

motus_fox <- read_csv("FilePath/Waggershauser_etal_SupportingAppendix1.csv")


motus_dog <- read_csv("FilePath/Waggershauser_etal_SupportingAppendix2.csv")


motus_combinations <- crossing(motus_fox, motus_dog)


motus_difs <- motus_combinations %>%
  mutate(sequence_dif = diag(adist(sequence_fox, sequence_dog))) %>%
  select(sequence_dif, id_fox, id_dog, sequence_fox, consensus_entry_fox, sequence_dog, consensus_entry_dog)


motus_dif_summary <- motus_difs %>%
  summarise(mean_dif = mean(sequence_dif),
            sd_dif = sd(sequence_dif),
            min_dif = min(sequence_dif),
            max_dif = max(sequence_dif))




#################################################





################################
######### GLM ANALYSIS ######### 

## Dataset 

dog_fieldvole <- read_csv("FilePath/Waggershauser_etal_SupportingAppendix3.csv")



## Fitting Dog ~ Year_season Model ##

year_season_glm <- glm(cbind(Yes, No) ~ year_season, family = "binomial", data = dog_fieldvole)

summary(year_season_glm)


# Validation
simulationOutput <- simulateResiduals(fittedModel = year_season_glm, n = 250)
plot(simulationOutput)
testDispersion(year_season_glm)



## Plot

# New data 
newdata <- tibble(year_season = c("2018.0", "2018.25", "2019.0", "2019.25"))


# Predict 
newdata$pred <-  predict(year_season_glm, newdata = newdata, se.fit = T, type = "link")$fit
newdata$se <-  predict(year_season_glm, newdata = newdata, se.fit = T, type = "link")$se.fit

#Backtransform
ilink  <- family(year_season_glm)$linkinv

newdata_ci95 <- newdata %>%
  mutate(pred_back = ilink(pred),
         ci_lower = ilink(pred - (1.96*se)),
         ci_upper = ilink(pred + (1.96*se))) %>%
  left_join(fox_year_season, by = "year_season")

#Prepare raw data for plotting
dog_fieldvole_plot <- dog_fieldvole %>%
  mutate(pred_back = Yes/(No+Yes),
         ci_upper = 0,
         ci_lower = 0)


dog_fieldvole_plot_summarise <- dog_fieldvole_plot %>%
  mutate(fo = fo/100) %>%
  group_by(year_season) %>%
  summarise(fo_mean = weighted.mean(fo, count_predator, na.rm = T),
            fo_sd = sqrt(weighted.mean((fo - fo_mean)^2, count_predator, na.rm = T))) %>%
  mutate(sd_upper = fo_mean + fo_sd,
         sd_lower = fo_mean - fo_sd)


# Merge predicted and raw data
newdata_vole <- newdata_ci95 %>%
  left_join(dog_fieldvole_plot_summarise, by = "year_season") %>%
  dplyr::select(-genetic_predator, -pred, -se, fo_sd) %>%
  pivot_longer(c(pred_back, fo_mean), values_to = "estimate", names_to = "method") %>%
  mutate(lower = case_when(method == "fo_mean" ~ sd_lower,
                           TRUE ~ ci_lower),
         upper = case_when(method == "fo_mean" ~ sd_upper,
                           TRUE ~ ci_upper)) %>%
  dplyr::select(-starts_with("ci_"), -starts_with("sd_")) %>%
  mutate(year_season = as.numeric(year_season),
         year_season = case_when(method == "fo_mean" ~ year_season + 0.02,
                                 TRUE ~ year_season))

# Plot
year_season_plot <- ggplot() +
  geom_hline(yintercept = 0.5, linetype = "dashed", size = 1, col = "dark grey") +
  # Dog and vole points from merged dataset of model output and summarised FO
  geom_point(data = newdata_vole, aes(y = estimate, x = as.numeric(year_season), shape = method, col = method), size = 3) +
  geom_line(data = newdata_vole, aes(y = estimate, x = as.numeric(year_season), col = method), show.legend = F) +
  geom_point(data = dog_fieldvole_plot, aes(y = pred_back, x = as.numeric(year_season), size = count_predator), alpha = 0.3, show.legend = F) +
  geom_linerange(data = newdata_vole, aes(y = estimate, x = as.numeric(year_season), ymax = upper, ymin = lower, col = method), lwd = 0.60, show.legend = F) +
  #Sample size printed at the bottom
  geom_text(data = newdata_ci95, aes(x = as.numeric(year_season), y = 0, label = paste("n = ", count_predator, sep="")), nudge_x = 0.02) +
  labs(y = "Occurrence", x = "Season-Year", tag = "(A)") +
  scale_y_continuous(limits = c(0, 1)) +
  scale_x_continuous(breaks = c(2018.0, 2018.25, 2019.0, 2019.25), labels = c("Winter-18", "Spring-18", "Winter-19", "Spring-19")) +
  scale_shape_manual(name = "", values = c("pred_back" = 19, "fo_mean" = 17), labels = c(expression(italic("M. agrestis")), expression(italic("C. familiaris"))),
                     guide = guide_legend(reverse = T)) +
  scale_color_manual(name = "", values = c("pred_back" = "black", "fo_mean" = "grey30"), labels = c(expression(italic("M. agrestis")), expression(italic("C. familiaris"))),
                     guide = guide_legend(reverse = T)) +
  theme(axis.title = element_text(size = 12, face = "bold"),
        axis.title.y = element_text(vjust = 2.5),
        axis.title.x = element_text(vjust = 1),
        axis.text = element_text(size = 10),
        axis.text.x = element_text(angle = 0, hjust = 0.5, vjust = 0.5),
        axis.line = element_line(),
        plot.tag.position = c(0.025,1),
        plot.margin = margin(t = 10, r = 10, b = 10, l = 10),
        legend.direction = "horizontal",
        legend.position = c(0.5, 0.90),
        legend.background = element_blank(),
        legend.key = element_blank(),
        legend.text = element_text(size = 10))
year_season_plot







## Fitting Vole ~ Year_Season Model ##

dog_fieldvole <- read_csv("FilePath/Waggershauser_etal_SupportingAppendix3.csv", col_types = list(year_season = col_character())) %>%
  rename(microtus_yes = count_prey) %>%
  mutate(microtus_no = count_predator - microtus_yes)


## Creating Total number of fox samples per year_season

fox_year_season <- dog_fieldvole %>%
  group_by(genetic_predator, year_season) %>%
  summarise(count_predator = sum(count_total)) %>%
  ungroup()


## Fitting Glm

vole_year_season_glm <- glm(cbind(microtus_yes, microtus_no) ~ year_season, family = "binomial", data = dog_fieldvole)


## Validation

simulationOutput <- simulateResiduals(fittedModel = vole_year_season_glm, n = 250)
plot(simulationOutput)
testDispersion(vole_year_season_glm)


## Predict

newdata <- tibble(year_season = c("2018.0", "2018.25", "2019.0", "2019.25")) %>%
  mutate(year_season = as_factor(year_season))

newdata$pred_dog <-  predict(dog_year_season_glm, newdata = newdata, se.fit = T, type = "link")$fit
newdata$se_dog <-  predict(dog_year_season_glm, newdata = newdata, se.fit = T, type = "link")$se.fit

newdata$pred_vole <-  predict(vole_year_season_glm, newdata = newdata, se.fit = T, type = "link")$fit
newdata$se_vole <-  predict(vole_year_season_glm, newdata = newdata, se.fit = T, type = "link")$se.fit

ilink  <- family(vole_year_season_glm)$linkinv

newdata_long <- newdata %>%
  pivot_longer(-year_season, names_to = c("param", "spec"), names_sep = "_", values_to = "value") %>%
  pivot_wider(names_from = c("param"), values_from = "value")


newdata_ci95 <- newdata_long %>%
  mutate(pred_back = ilink(pred),
         ci_lower = ilink(pred - (1.96*se)),
         ci_upper = ilink(pred + (1.96*se))) %>%
  left_join(fox_year_season, by = "year_season") %>%
  mutate(year_season = as.numeric(year_season),
         year_season = case_when(spec == "vole" ~ year_season + 0.02,
                                 TRUE ~ year_season))


dog_fieldvole_plot <- dog_fieldvole %>%
  mutate(pred_back = Yes/(No+Yes),
         ci_upper = 0,
         ci_lower = 0)


## Plotting 

year_season_plot <- ggplot() +
  # Vertical 0.5 line
  geom_hline(yintercept = 0.5, linetype = "dashed", size = 1, col = "dark grey") +
  # Dog and vole points from merged dataset of model output and summarised FO
  geom_point(data = newdata_ci95, aes(y = pred_back, x = as.numeric(year_season), shape = spec, col = spec), size = 3) +
  geom_line(data = newdata_ci95, aes(y = pred_back, x = as.numeric(year_season), col = spec), show.legend = F) +
  geom_point(data = dog_fieldvole_plot, aes(y = pred_back, x = as.numeric(year_season), size = count_predator), alpha = 0.3, show.legend = F) +
  geom_linerange(data = newdata_ci95, aes(y = pred_back, x = as.numeric(year_season), ymax = ci_upper, ymin = ci_lower, col = spec), lwd = 0.60, show.legend = F) + 
  #Sample size printed at the bottom
  geom_text(data = filter(newdata_ci95, spec == "dog"), aes(x = as.numeric(year_season), y = 0, label = paste("n = ", count_predator, sep="")), nudge_x = 0.02) +
  labs(y = "Probability of Occurrence", x = "Season-Year", tag = "(A)") +
  scale_y_continuous(limits = c(0, 1)) +
  scale_x_continuous(breaks = c(2018.0, 2018.25, 2019.0, 2019.25), labels = c("Winter-18", "Spring-18", "Winter-19", "Spring-19")) +
  scale_shape_manual(name = "", values = c("dog" = 19, "vole" = 17), labels = c(expression(italic("M. agrestis")), expression(italic("C. familiaris"))),
                     guide = guide_legend(reverse = T)) +
  scale_color_manual(name = "", values = c("dog" = "black", "vole" = "grey30"), labels = c(expression(italic("M. agrestis")), expression(italic("C. familiaris"))),
                     guide = guide_legend(reverse = T)) +
  theme(axis.title = element_text(size = 12, face = "bold"),
        axis.title.y = element_text(vjust = 2.5),
        axis.title.x = element_text(vjust = 1),
        axis.text = element_text(size = 10),
        axis.text.x = element_text(angle = 0, hjust = 0.5, vjust = 0.5),
        axis.line = element_line(),
        plot.tag.position = c(0.025,1),
        plot.margin = margin(t = 10, r = 10, b = 10, l = 10),
        legend.direction = "horizontal",
        legend.position = c(0.5, 0.90),
        legend.background = element_blank(),
        legend.key = element_blank(),
        legend.text = element_text(size = 10))

year_season_plot








## Fitting Dog ~ Field Vole Model ##

fieldvole_glm <- glm(cbind(Yes, No) ~ fo, family = "binomial", data = dog_fieldvole)

summary(fieldvole_glm)


# Validation 
simulationOutput <- simulateResiduals(fittedModel = fieldvole_glm, n = 250)
plot(simulationOutput)
testDispersion(fieldvole_glm)


# Newdata
newdata_fieldvole <- tibble(fo = seq(min(dog_fieldvole$fo), max(dog_fieldvole$fo), length = 200))

# Predict
newdata_fieldvole$pred <-  predict(fieldvole_glm, newdata= newdata_fieldvole, se.fit = T, type = "link")$fit
newdata_fieldvole$se <-  predict(fieldvole_glm, newdata = newdata_fieldvole, se.fit = T, type = "link")$se.fit


# Backtransform
ilink  <- family(fieldvole_glm)$linkinv

newdata_fieldvole_ci95 <- newdata_fieldvole %>%
  mutate(pred_back = ilink(pred),
         ci_lower = ilink(pred - (1.96*se)),
         ci_upper = ilink(pred + (1.96*se)))


# Plot
fieldvole_plot <- ggplot(data = newdata_fieldvole_ci95, aes(x = fo, y = pred_back)) +
  geom_ribbon(aes(ymin = ci_lower,
                  ymax = ci_upper), 
              fill = "grey35", alpha = 0.5) +
  geom_line(stat = "identity", size = 1, lineend = "round") +
  geom_point(data = dog_fieldvole_plot, aes(size = count_predator), alpha = 0.3, show.legend = F) +
  labs(y = expression(bolditalic("C. familiaris ")*bold("Probability of Ocurrence")), x = expression(bolditalic("M. agrestis")*bold(" Frequency of Occurrence")), tag = "(B)") +
  scale_y_continuous(limits = c(0, 1)) +
  scale_x_continuous(breaks = c(0, 25, 50, 75, 100), labels = c("0", "25", "50", "75", "100")) +
  theme(axis.title = element_text(size = 12),
        axis.title.y = element_text(vjust = 2.5),
        axis.title.x = element_text(vjust = 1),
        axis.text = element_text(size = 10),
        axis.text.x = element_text(angle = 0, hjust = 0.5, vjust = 0.5),
        axis.line = element_line(),
        plot.tag.position = c(0.025,1),
        plot.margin = margin(t = 10, r = 10, b = 7, l = 10))
fieldvole_plot


# Paneled figure 
model_output <- grid.arrange(year_season_plot, fieldvole_plot, nrow = 1)




################################





#########################
#### PCR READ PLOTS ####


samples_vole_log <- read_csv("FilePath/Waggershauser_etal_SupportingAppendix4.csv")

# Vole reads over fox reads
vole_fox_plot <- ggplot(data = subset(samples_vole_log), aes(y = read_Microtus_log, x = read_Vulpes_log)) +
  geom_jitter(height = 0.1, width = 0.1, alpha = 0.5, size = 1) +
  geom_hline(yintercept = 0.18, linetype = "dashed", col = "dark grey", size = 1) +
  geom_vline(xintercept = 0.5, linetype = "dashed", col = "dark grey", size = 1) +
  scale_x_continuous(limits = c(-0.11,5), breaks = c(0, 1, 2, 3, 4, 5), labels = c(0, 10, 100, 1000, 10000, "100000")) + 
  scale_y_continuous(limits = c(-0.11,5), breaks = c(0, 1, 2, 3, 4, 5), labels = c(0, 10, 100, 1000, 10000, "100000")) + 
  labs(y = expression(italic(log)["10"]*"(Reads"*italic(" M. agrestis")*")"), x = expression(italic(log)["10"]*"(Reads"*italic(" V. vulpes")*")"), tag = "(B)") +
  theme(axis.line = element_line(),
        axis.title.x = element_text(vjust = -1),
        plot.margin = margin(t = 0.5, r = 0.5, b = 0.5, l = 0.5, unit = "cm"),
        plot.tag.position = c(0.025,1)) +
  geom_quantile(data = subset(samples_vole_log, read_Microtus_log > 0 & read_Vulpes_log > 0), quantiles = 0.90, method = "rq", formula = "y ~ x",
                size = 1, col = "black")


# dog reads over fox reads
dog_fox_plot <-   ggplot(data = subset(samples_vole_log), aes(y = read_Canis_log, x = read_Vulpes_log)) +
  geom_jitter(height = 0.1, width = 0.1, alpha = 0.5, size = 1) +
  geom_hline(yintercept = 0.18, linetype = "dashed", col = "dark grey", size = 1) +
  geom_vline(xintercept = 0.5, linetype = "dashed", col = "dark grey", size = 1) +
  scale_x_continuous(limits = c(-0.11,5), breaks = c(0, 1, 2, 3, 4, 5), labels = c(0, 10, 100, 1000, 10000, "100000")) + 
  scale_y_continuous(limits = c(-0.11,5), breaks = c(0, 1, 2, 3, 4, 5), labels = c(0, 10, 100, 1000, 10000, "100000")) + 
  labs(y = expression(italic(log)["10"]*"(Reads"*italic(" C. familiaris")*")"), x = expression(italic(log)["10"]*"(Reads"*italic(" V. vulpes")*")"), tag = "(A)") +
  theme(axis.line = element_line(),
        axis.title.x = element_text(vjust = -1),
        plot.margin = margin(t = 0.5, r = 0.5, b = 0.5, l = 0.5, unit = "cm"),
        plot.tag.position = c(0.025,1)) +
  geom_quantile(data = subset(samples_vole_log, read_Canis_log > 0 & read_Vulpes_log > 0), quantiles = 0.90, method = "rq", formula = "y ~ x",
                size = 1, col = "black")


# paneled figure
grid.arrange(dog_fox_plot, vole_fox_plot, nrow = 1)

dog_vole_fox_plot <- grid.arrange(dog_fox_plot, vole_fox_plot, nrow = 1)



## PCR reads over read depth

# dog
dog_depth_plot <- ggplot(data = subset(samples_vole_log), aes(y = read_Canis_log, x = read_count_log)) +
  geom_abline(intercept = 0, slope = 1, linetype = "solid", col = "darkgrey", size = 5) +
  geom_jitter(height = 0.1, width = 0.1, alpha = 0.5, size = 1) +
  scale_x_continuous(limits = c(-0.11,5), breaks = c(0, 1, 2, 3, 4, 5), labels = c(0, 10, 100, 1000, 10000, "100000")) +
  scale_y_continuous(limits = c(-0.11,5), breaks = c(0, 1, 2, 3, 4, 5), labels = c(0, 10, 100, 1000, 10000, "100000")) +
  labs(y = expression(italic(log)["10"]*"(Reads"*italic(" C. familiaris")*")"), x = expression(italic(log)["10"]*"(Read Depth)"), tag = "(A)") +
  theme(axis.line = element_line(),
        axis.title.x = element_text(vjust = -1),
        plot.margin = margin(t = 0.5, r = 0.5, b = 0.5, l = 0.5, unit = "cm"),
        plot.tag.position = c(0.025,1))


# vole
vole_depth_plot <- ggplot(data = subset(samples_vole_log), aes(y = read_Microtus_log, x = read_count_log)) +
  geom_abline(intercept = 0, slope = 1, linetype = "solid", col = "darkgrey", size = 5) +
  geom_jitter(height = 0.1, width = 0.1, alpha = 0.5, size = 1) +
  scale_x_continuous(limits = c(-0.11,5), breaks = c(0, 1, 2, 3, 4, 5), labels = c(0, 10, 100, 1000, 10000, "100000")) +
  scale_y_continuous(limits = c(-0.11,5), breaks = c(0, 1, 2, 3, 4, 5), labels = c(0, 10, 100, 1000, 10000, "100000")) +
  labs(y = expression(italic(log)["10"]*"(Reads"*italic(" M. agrestis")*")"), x = expression(italic(log)["10"]*"(Read Depth)"), tag = "(B)") +
  theme(axis.line = element_line(),
        axis.title.x = element_text(vjust = -1),
        plot.margin = margin(t = 0.5, r = 0.5, b = 0.5, l = 0.5, unit = "cm"),
        plot.tag.position = c(0.025,1))


# fox
fox_depth_plot <- ggplot(data = subset(samples_vole_log), aes(y = read_Vulpes_log, x = read_count_log)) +
  geom_abline(intercept = 0, slope = 1, linetype = "solid", col = "darkgrey", size = 5) +
  geom_jitter(height = 0.1, width = 0.1, alpha = 0.5, size = 1) + 
  scale_x_continuous(limits = c(-0.11,5), breaks = c(0, 1, 2, 3, 4, 5), labels = c(0, 10, 100, 1000, 10000, "100000")) +
  scale_y_continuous(limits = c(-0.11,5), breaks = c(0, 1, 2, 3, 4, 5), labels = c(0, 10, 100, 1000, 10000, "100000")) +
  labs(y = expression(italic(log)["10"]*"(Reads"*italic(" V. vulpes")*")"), x = expression(italic(log)["10"]*"(Read Depth)"), tag = "(C)") +
  theme(axis.line = element_line(),
        axis.title.x = element_text(vjust = -1),
        plot.margin = margin(t = 0.5, r = 0.5, b = 0.5, l = 0.5, unit = "cm"),
        plot.tag.position = c(0.025,1))


# paneled figure
grid.arrange(dog_depth_plot, vole_depth_plot, fox_depth_plot, nrow = 1)


depth_plot <- grid.arrange(dog_depth_plot, vole_depth_plot, fox_depth_plot, nrow = 1)


#########################














